Crate nym_vesting_contract_common

Crate nym_vesting_contract_common 

Re-exports

pub use account::Account;
pub use error::VestingContractError;
pub use messages::ExecuteMsg;
pub use messages::InitMsg;
pub use messages::MigrateMsg;
pub use messages::QueryMsg;
pub use types::*;

Modules

account
error
events
messages
types

Structs

AccountVestingCoins
Basic information regarding particular vesting account alongside the amount of vesting coins.
AccountsResponse
Response containing basic vesting account information
AllDelegationsResponse
Response containing paged list of all vesting delegations made using vesting coins.
BaseVestingAccountInfo
Basic information regarding particular vesting account
DelegationTimesResponse
Response containing timestamps of all delegations made towards particular mixnode by given vesting account.
OriginalVestingResponse
Details about the original vesting specification used when the account was created.
VestingCoinsResponse
Response containing vesting coins held in this contract