Re-exports
pub use account::Account;pub use error::VestingContractError;pub use messages::ExecuteMsg;pub use messages::InitMsg;pub use messages::MigrateMsg;pub use messages::QueryMsg;pub use types::*;
Modules
Structs
- Account
Vesting Coins - Basic information regarding particular vesting account alongside the amount of vesting coins.
- Accounts
Response - Response containing basic vesting account information
- AllDelegations
Response - Response containing paged list of all vesting delegations made using vesting coins.
- Base
Vesting Account Info - Basic information regarding particular vesting account
- Delegation
Times Response - Response containing timestamps of all delegations made towards particular mixnode by given vesting account.
- Original
Vesting Response - Details about the original vesting specification used when the account was created.
- Vesting
Coins Response - Response containing vesting coins held in this contract